==> bigloo2.9a.tar.gz: bigloo2.9a/api/mail/src/Llib/exc.scm <==
;*=====================================================================*/
;*    serrano/prgm/project/bigloo/api/mail/src/Llib/exc.scm            */
;*    -------------------------------------------------------------    */
;*    Author      :  Manuel Serrano                                    */
;*    Creation    :  Wed Mar 23 15:28:11 2005                          */
;*    Last change :  Tue May 17 07:25:26 2005 (serrano)                */
;*    Copyright   :  2005 Manuel Serrano                               */
;*    -------------------------------------------------------------    */
;*    MAIL exceptions                                                  */
;*=====================================================================*/

;*---------------------------------------------------------------------*/
;*    The module                                                       */
;*---------------------------------------------------------------------*/
(module __mail_exception
   
   (export (class &imap-parse-error::&io-parse-error)
	   (class &imap-error::&error)

	   (%imap-read-error msg obj)
	   (%imap-login-error msg obj)
	   (%imap-command-error proc msg obj)))

;*---------------------------------------------------------------------*/
;*    %imap-read-error ...                                             */
;*---------------------------------------------------------------------*/
(define (%imap-read-error msg obj)
   (raise
    (instantiate::&imap-parse-error
       (proc 'imap-read)
       (msg msg)
       (obj obj))))

;*---------------------------------------------------------------------*/
;*    %imap-login-error ...                                            */
;*---------------------------------------------------------------------*/
(define (%imap-login-error msg obj)
   (raise
    (instantiate::&imap-error
       (proc 'imap-login)
       (msg msg)
       (obj obj))))
   
;*---------------------------------------------------------------------*/
;*    %imap-command-error ...                                          */
;*---------------------------------------------------------------------*/
(define (%imap-command-error proc msg obj)
   (raise
    (instantiate::&imap-error
       (proc proc)
       (msg msg)
       (obj obj))))

==> bigloo3.1a.tar.gz: bigloo3.1a/api/mail/src/Llib/exc.scm <==
;*=====================================================================*/
;*    serrano/prgm/project/bigloo/api/mail/src/Llib/exc.scm            */
;*    -------------------------------------------------------------    */
;*    Author      :  Manuel Serrano                                    */
;*    Creation    :  Wed Mar 23 15:28:11 2005                          */
;*    Last change :  Tue Jun  5 09:18:05 2007 (serrano)                */
;*    Copyright   :  2005-07 Manuel Serrano                            */
;*    -------------------------------------------------------------    */
;*    MAIL exceptions                                                  */
;*=====================================================================*/

;*---------------------------------------------------------------------*/
;*    The module                                                       */
;*---------------------------------------------------------------------*/
(module __mail_exception
   
   (export (class &imap-parse-error::&io-parse-error)
	   (class &imap-error::&error)

	   (%imap-read-error msg obj)
	   (%imap-login-error msg obj)
	   (%imap-command-error proc msg obj)))

;*---------------------------------------------------------------------*/
;*    parse-error ...                                                  */
;*---------------------------------------------------------------------*/
(define (parse-error proc message obj port)
   (raise
    (instantiate::&imap-parse-error
       (proc proc)
       (msg message)
       (obj (if (char? obj)
		(string-append "{" (string obj) "}" (read-line port))
		obj))
       (fname (input-port-name port))
       (location (input-port-position port)))))

;*---------------------------------------------------------------------*/
;*    %imap-read-error ...                                             */
;*---------------------------------------------------------------------*/
(define (%imap-read-error msg obj)
   (raise
    (instantiate::&imap-parse-error
       (proc 'imap-read)
       (msg msg)
       (obj obj))))

;*---------------------------------------------------------------------*/
;*    %imap-login-error ...                                            */
;*---------------------------------------------------------------------*/
(define (%imap-login-error msg obj)
   (raise
    (instantiate::&imap-error
       (proc 'imap-login)
       (msg msg)
       (obj obj))))
   
;*---------------------------------------------------------------------*/
;*    %imap-command-error ...                                          */
;*---------------------------------------------------------------------*/
(define (%imap-command-error proc msg obj)
   (raise
    (instantiate::&imap-error
       (proc proc)
       (msg msg)
       (obj obj))))
